@@ -19,8 +19,12 @@ def __process_word_data(word_data: WordData,
                         word_list: List[WordData]) -> OutputWord:
     kanji = word_data.japanese[0].word
     kana = word_data.japanese[0].reading
-    same_reading = [x.japanese[0].word for x in word_list
-                    if x != word_data and x.japanese[0].reading == kana]
+    same_reading = [
+        x.japanese[0].word for x in word_list
+        if x != word_data
+        and x.japanese[0].reading == kana
+        and x.japanese[0].word is not None
+    ]
     if same_reading:
         kana = f'{kana} (not: {", ".join(same_reading)})'
 
